==> jc-1.4.0.tar.gz: soot/util/JavaInputStream.h <==
// public class soot.util.JavaInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fcb4f89459205f2 soot_util_JavaInputStream
// @dep_class ce4d97b1a0c5a527 soot_util_SootInputStream

// header file dependencies
// @dep_header soot_util_SootInputStream

#include "soot/util/SootInputStream.h"

#ifndef _JC_soot_util_JavaInputStream_H_
#define _JC_soot_util_JavaInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_util_JavaInputStream$sub_refs	_jc_soot_util_JavaInputStream$sub_refs;
typedef struct _jc_soot_util_JavaInputStream$sub_nonrefs	_jc_soot_util_JavaInputStream$sub_nonrefs;
typedef struct _jc_soot_util_JavaInputStream$refs	_jc_soot_util_JavaInputStream$refs;
typedef struct _jc_soot_util_JavaInputStream$nonrefs	_jc_soot_util_JavaInputStream$nonrefs;
typedef struct _jc_soot_util_JavaInputStream$object	_jc_soot_util_JavaInputStream$object;

typedef const struct _jc_soot_util_JavaInputStream$vmethods	_jc_soot_util_JavaInputStream$vmethods;
typedef const struct _jc_soot_util_JavaInputStream$vtable	_jc_soot_util_JavaInputStream$vtable;
typedef const struct _jc_soot_util_JavaInputStream$vtype	_jc_soot_util_JavaInputStream$vtype;

// Constructors
extern void _jc_soot_util_JavaInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_soot_util_JavaInputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods structure
struct _jc_soot_util_JavaInputStream$vmethods {
};

// Vtable
struct _jc_soot_util_JavaInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_soot_util_SootInputStream$vmethods	soot_util_SootInputStream;
	_jc_soot_util_JavaInputStream$vmethods	soot_util_JavaInputStream;
};

// Vtype
struct _jc_soot_util_JavaInputStream$vtype {
	_jc_type			type;
	_jc_soot_util_JavaInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_JavaInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_JavaInputStream$refs {
    _jc_soot_util_JavaInputStream$sub_refs	soot_util_JavaInputStream;
    _jc_soot_util_SootInputStream$sub_refs	soot_util_SootInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_JavaInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_JavaInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_soot_util_SootInputStream$sub_nonrefs	soot_util_SootInputStream;
    _jc_soot_util_JavaInputStream$sub_nonrefs	soot_util_JavaInputStream;
};

// Object instance structure
struct _jc_soot_util_JavaInputStream$object {
	_jc_soot_util_JavaInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_JavaInputStream$vtype	*vtype;
	_jc_soot_util_JavaInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_JavaInputStream$vtype _jc_soot_util_JavaInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_JavaInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_JavaInputStream$class_object;

#endif	/* _JC_soot_util_JavaInputStream_H_ */

==> jc-1.4.6.tar.gz: soot/util/JavaInputStream.h <==
// public class soot.util.JavaInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fcb4f89459205f2 soot_util_JavaInputStream
// @dep_class ce4d97b1a0c5a527 soot_util_SootInputStream

// header file dependencies
// @dep_header soot_util_SootInputStream

#include "soot/util/SootInputStream.h"

#ifndef _JC_soot_util_JavaInputStream_H_
#define _JC_soot_util_JavaInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_util_JavaInputStream$sub_refs	_jc_soot_util_JavaInputStream$sub_refs;
typedef struct _jc_soot_util_JavaInputStream$sub_nonrefs	_jc_soot_util_JavaInputStream$sub_nonrefs;
typedef struct _jc_soot_util_JavaInputStream$refs	_jc_soot_util_JavaInputStream$refs;
typedef struct _jc_soot_util_JavaInputStream$nonrefs	_jc_soot_util_JavaInputStream$nonrefs;
typedef struct _jc_soot_util_JavaInputStream$object	_jc_soot_util_JavaInputStream$object;

typedef const struct _jc_soot_util_JavaInputStream$vmethods	_jc_soot_util_JavaInputStream$vmethods;
typedef const struct _jc_soot_util_JavaInputStream$vtable	_jc_soot_util_JavaInputStream$vtable;
typedef const struct _jc_soot_util_JavaInputStream$vtype	_jc_soot_util_JavaInputStream$vtype;

// Constructors
extern void _jc_soot_util_JavaInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_soot_util_JavaInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_JavaInputStream$vmethods {
};

// Vtable
struct _jc_soot_util_JavaInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_soot_util_SootInputStream$vmethods	soot_util_SootInputStream;
	_jc_soot_util_JavaInputStream$vmethods	soot_util_JavaInputStream;
};

// Vtype
struct _jc_soot_util_JavaInputStream$vtype {
	_jc_type			type;
	_jc_soot_util_JavaInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_JavaInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_JavaInputStream$refs {
    _jc_soot_util_JavaInputStream$sub_refs	soot_util_JavaInputStream;
    _jc_soot_util_SootInputStream$sub_refs	soot_util_SootInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_JavaInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_JavaInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_soot_util_SootInputStream$sub_nonrefs	soot_util_SootInputStream;
    _jc_soot_util_JavaInputStream$sub_nonrefs	soot_util_JavaInputStream;
};

// Object instance structure
struct _jc_soot_util_JavaInputStream$object {
	_jc_soot_util_JavaInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_JavaInputStream$vtype	*vtype;
	_jc_soot_util_JavaInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_JavaInputStream$vtype _jc_soot_util_JavaInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_JavaInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_JavaInputStream$class_object;

#endif	/* _JC_soot_util_JavaInputStream_H_ */
